@@ -86,7 +86,7 @@
 #define KARCHIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KARCHIVE_NO_DEPRECATED
-#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
+#  define KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KARCHIVE_NO_DEPRECATED_WARNINGS
 #  define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KARCHIVE_DEPRECATED_WARNINGS_SINCE KARCHIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x54f00
+#    define KARCHIVE_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -118,5 +118,12 @@
 #define KARCHIVE_DEPRECATED_VERSION_5(minor, text)      KARCHIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KARCHIVE_DEPRECATED_VERSION(major, minor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KARCHIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KARCHIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KARCHIVE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KARCHIVE_DEPRECATED_VERSION(major, minor, text)
+#  define KARCHIVE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KARCHIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KARCHIVE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KARCHIVE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KARCHIVE_EXPORT_H */
